@@ -1,39 +1,37 @@
-from functools import partial
-from typing import TYPE_CHECKING, Optional, Generator, List, Tuple, Set
 import logging
-
-from PySide6.QtWidgets import QMessageBox
+from typing import TYPE_CHECKING, Generator, List, Optional, Set, Tuple
 
 from angr import KnowledgeBase
-from angr.analyses.reaching_definitions.external_codeloc import ExternalCodeLocation
-from angr.analyses.reaching_definitions.dep_graph import DepGraph
 from angr.analyses.reaching_definitions.call_trace import CallTrace
-from angr.knowledge_plugins.key_definitions.constants import OP_BEFORE
-from angr.knowledge_plugins.key_definitions.atoms import Register, MemoryLocation, SpOffset
+from angr.analyses.reaching_definitions.dep_graph import DepGraph
+from angr.analyses.reaching_definitions.external_codeloc import ExternalCodeLocation
+from angr.calling_conventions import DEFAULT_CC, SimCC, SimRegArg
 from angr.knowledge_plugins import Function
-from angr.calling_conventions import DEFAULT_CC, SimCC, SimRegArg, SimStackArg
+from angr.knowledge_plugins.key_definitions.atoms import Register
+from angr.knowledge_plugins.key_definitions.constants import OP_BEFORE
 from angr.sim_type import SimType
+from PySide6.QtWidgets import QMessageBox
+
+from angrmanagement.logic.threads import gui_thread_schedule_async
 
 from .job import Job
-from ...logic.threads import gui_thread_schedule_async
 
 try:
     import argument_resolver
-    from argument_resolver.handlers import handler_factory, StdioHandlers, StdlibHandlers, StringHandlers
-    from argument_resolver.transitive_closure import transitive_closures_from_defs
     from argument_resolver.call_trace_visitor import CallTraceSubject
+    from argument_resolver.handlers import StdioHandlers, StdlibHandlers, StringHandlers, handler_factory
+    from argument_resolver.transitive_closure import transitive_closures_from_defs
 except ImportError:
     argument_resolver = None
 
 if TYPE_CHECKING:
-    from angr.knowledge_plugins.key_definitions.definition import Definition
-    from angr.knowledge_plugins.key_definitions.atoms import Atom
     from angr.analyses.reaching_definitions import ReachingDefinitionsAnalysis
-    from ...plugins.dep_viewer import DependencyViewer
-    from ..instance import Instance
+    from angr.knowledge_plugins.key_definitions.atoms import Atom
+
+    from angrmanagement.data.instance import Instance
 
 
-l = logging.getLogger(name=__name__)
+log = logging.getLogger(name=__name__)
 
 
 class DependencyAnalysisJob(Job):
@@ -128,10 +126,10 @@ class DependencyAnalysisJob(Job):
                 try:
                     cc = transitive_closures_from_defs(all_defs, dep)
                 except Exception:  # pylint:disable=broad-except
-                    l.warning("Exception occurred when computing transitive clousure. Skip.")
+                    log.warning("Exception occurred when computing transitive clousure. Skip.")
                     continue
 
-                # determine if there is any values are marked as coming from External. these values are not resolved
+                # determine if there is any values are marked as coming from Externalog. these values are not resolved
                 # within the current call-depth range
                 has_external = False
                 for def_, graph in closures.items():
@@ -145,7 +143,7 @@ class DependencyAnalysisJob(Job):
                 if not has_external:
                     # fully resolved - we should exclude this function for future exploration
                     current_function_address = dep.subject.content.current_function_address()
-                    l.info(
+                    log.info(
                         "Exclude function %#x from future slices since the data dependencies are fully resolved.",
                         current_function_address,
                     )
@@ -189,8 +187,8 @@ class DependencyAnalysisJob(Job):
         else:
             raise TypeError("Unsupported type of subject %s." % type(subject))
 
-        # peek into the callgraph and discover all functions reaching the sink within N layers of calls, which is determined
-        # by the depth parameter
+        # peek into the callgraph and discover all functions reaching the sink within N layers of calls, which is
+        # determined by the depth parameter
         queue: List[Tuple[CallTrace, int]] = [(CallTrace(sink.addr), 0)]
         starts: Set[CallTrace] = set()
         encountered: Set[int] = set(excluded_funtions)
@@ -214,7 +212,7 @@ class DependencyAnalysisJob(Job):
                     queue.append(item)
             encountered |= callers
 
-        l.info("Discovered %d function starts at call-depth %d for sink %r.", len(starts), max_depth, sink)
+        log.info("Discovered %d function starts at call-depth %d for sink %r.", len(starts), max_depth, sink)
 
         for idx, start in enumerate(starts):
             handler = Handler(project, False, sink_function=sink, sink_atoms=sink_atoms, cfg=kb.cfgs[0])
@@ -228,7 +226,7 @@ class DependencyAnalysisJob(Job):
                     dep_graph=DepGraph(),
                 )
             except Exception:  # pylint:disable=broad-except
-                l.warning("Failed to compute dependencies for function %s.", start, exc_info=True)
+                log.warning("Failed to compute dependencies for function %s.", start, exc_info=True)
                 continue
             yield idx, len(starts), rda
 
@@ -264,5 +262,5 @@ class DependencyAnalysisJob(Job):
         try:
             view.reload()
         except Exception:
-            l.warning("An error occurred when displaying the closures.", exc_info=True)
+            log.warning("An error occurred when displaying the closures.", exc_info=True)
         inst.workspace.view_manager.raise_view(view)
