@@ -1,3 +1,9 @@
-from .chess_url_handler import ChessUrlHandler
 from .chess_connector import ChessConnector
+from .chess_url_handler import ChessUrlHandler
 from .poi_plugin import POIViewer
+
+__all__ = [
+    "ChessConnector",
+    "ChessUrlHandler",
+    "POIViewer",
+]
