@@ -5,8 +5,8 @@ import math
 import threading
 import time
 
-from tornado.platform.asyncio import AnyThreadEventLoopPolicy
 from PySide6.QtGui import QColor
+from tornado.platform.asyncio import AnyThreadEventLoopPolicy
 
 from angrmanagement.config import Conf
 from angrmanagement.errors import UnexpectedStatusCodeError
@@ -16,12 +16,12 @@ from angrmanagement.utils.io import download_url
 
 from .parse_trace import trace_to_bb_addrs
 
-l = logging.getLogger(__name__)
+log = logging.getLogger(__name__)
 
 try:
     import slacrs.model
-except ImportError as ex:
-    l.error("You don't have slacrs module installed locally, CoveragePlugin going to have a bad time.")
+except ImportError:
+    log.error("You don't have slacrs module installed locally, CoveragePlugin going to have a bad time.")
 
 
 def generate_light_gradients(color, number, lightness=20):
@@ -170,7 +170,7 @@ class CoveragePlugin(BasePlugin):
             self.bbl_coverage_hash = 0
 
     def update_coverage_from_list(self, trace_addrs):
-        l.info("Processing %d from the trace", len(trace_addrs))
+        log.info("Processing %d from the trace", len(trace_addrs))
         with self.coverage_lock:
             for addr in trace_addrs:
                 self.bbl_coverage.add(addr)
@@ -198,25 +198,25 @@ class CoveragePlugin(BasePlugin):
     def update_one_coverage(self, trace):
         with self.coverage_lock:
             if trace.id in self.seen_traces:
-                l.info("Already seen trace %s, skipping", trace.id)
+                log.info("Already seen trace %s, skipping", trace.id)
                 return
 
-        l.info("Processing trace %s %s %s", trace.id, trace.input_id, trace.created_at)
+        log.info("Processing trace %s %s %s", trace.id, trace.input_id, trace.created_at)
 
         if not Conf.checrs_rest_endpoint_url:
-            l.error("Unable to fetch trace %d because there is no CHECRS REST endpoint.", trace.id)
+            log.error("Unable to fetch trace %d because there is no CHECRS REST endpoint.", trace.id)
             return
 
         url = f"{Conf.checrs_rest_endpoint_url}v1/targets/{self.connector.target_image_id}/seeds/{trace.input_id}/trace"
         try:
             trace_bytes = download_url(url, parent=self.workspace._main_window, to_file=False)
         except UnexpectedStatusCodeError:
-            l.exception("Unable to download %s.", url)
+            log.exception("Unable to download %s.", url)
             return
         try:
             parsed_trace = json.loads(trace_bytes)
         except json.JSONDecodeError:
-            l.exception("Unable to parse %s as JSON.", url)
+            log.exception("Unable to parse %s as JSON.", url)
             return
 
         bbl_addrs = trace_to_bb_addrs(parsed_trace, self.workspace.main_instance.project, TRACE_BASE)
@@ -224,7 +224,7 @@ class CoveragePlugin(BasePlugin):
 
         with self.coverage_lock:
             self.seen_traces.add(trace.id)
-        l.info("Done processing trace %s.", trace.id)
+        log.info("Done processing trace %s.", trace.id)
 
     def listen_for_events(self):
         asyncio.set_event_loop_policy(AnyThreadEventLoopPolicy())
