@@ -7,13 +7,12 @@ from .trace_statistics import TraceStatistics
 try:
     from slacrs import Slacrs
     from slacrs.model import Input
-except ImportError as ex:
+except ImportError:
     Slacrs = None
     HumanFatigue = None
 
 
 class MultiTrace:
-
     HIT_COLOR = QColor(0x00, 0x99, 0x00, 0x60)
     MISS_COLOR = QColor(0xEE, 0xEE, 0xEE)
     FUNCTION_NOT_VISITED_COLOR = QColor(0x99, 0x00, 0x00, 0x20)
