@@ -5,6 +5,7 @@ from PySide6.QtCore import QSize, Qt
 from PySide6.QtGui import QIcon
 from PySide6.QtWidgets import (
     QCheckBox,
+    QComboBox,
     QDialog,
     QDialogButtonBox,
     QFrame,
@@ -24,6 +25,7 @@ from angrmanagement.data.analysis_options import (
     AnalysesConfiguration,
     AnalysisOption,
     BoolAnalysisOption,
+    ChoiceAnalysisOption,
     IntAnalysisOption,
 )
 
@@ -49,6 +51,8 @@ class AnalysisOptionWidgetMapper:
             return BoolAnalysisOptionWidgetMapper(option)
         elif isinstance(option, IntAnalysisOption):
             return IntAnalysisOptionWidgetMapper(option)
+        elif isinstance(option, ChoiceAnalysisOption):
+            return ChoiceAnalysisOptionWidgetMapper(option)
         else:
             raise ValueError("Mapper not implemented")
 
@@ -69,8 +73,8 @@ class BoolAnalysisOptionWidgetMapper(AnalysisOptionWidgetMapper):
         self.widget.stateChanged.connect(self._on_checkbox_changed)
         return self.widget
 
-    def _on_checkbox_changed(self, state):
-        self.option.value = state == Qt.Checked
+    def _on_checkbox_changed(self, _):
+        self.option.value = self.widget.isChecked()
 
 
 class IntAnalysisOptionWidgetMapper(AnalysisOptionWidgetMapper):
@@ -108,6 +112,42 @@ class IntAnalysisOptionWidgetMapper(AnalysisOptionWidgetMapper):
         self.option.value = value
 
 
+class ChoiceAnalysisOptionWidgetMapper(AnalysisOptionWidgetMapper):
+    """
+    Analysis option widget creation and event handling for choice options.
+    """
+
+    option: ChoiceAnalysisOption
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.combobox = None
+
+    def create_widget(self, parent=None) -> QWidget:
+        self.combobox = QComboBox()
+        for data, txt in self.option.choices.items():
+            self.combobox.addItem(txt, data)
+        self.combobox.setCurrentIndex(self.combobox.findData(self.option.value))
+        self.combobox.currentIndexChanged.connect(self._on_combo_changed)
+
+        lbl = QLabel()
+        lbl.setText(self.option.display_name)
+        if self.option.tooltip:
+            lbl.setToolTip(self.option.tooltip)
+
+        layout = QHBoxLayout()
+        layout.addWidget(lbl)
+        layout.addStretch()
+        layout.addWidget(self.combobox)
+
+        self.widget = QWidget(parent)
+        self.widget.setLayout(layout)
+        return self.widget
+
+    def _on_combo_changed(self, index):
+        self.option.value = self.combobox.itemData(index)
+
+
 class AnalysisOptionsDialog(QDialog):
     """
     Dialog displaying available analyses and configuration options.
