@@ -1,6 +1,7 @@
-from PySide6.QtWidgets import QDialog, QVBoxLayout
 from PySide6.QtCore import Qt
-from ..widgets.filesystem_table import QFileSystemTable
+from PySide6.QtWidgets import QDialog, QVBoxLayout
+
+from angrmanagement.ui.widgets.filesystem_table import QFileSystemTable
 
 
 class FilesystemMount(QDialog):
