@@ -1,7 +1,7 @@
 from PySide6.QtGui import Qt
-from PySide6.QtWidgets import QDialog, QVBoxLayout, QLabel, QGridLayout, QTextEdit
+from PySide6.QtWidgets import QDialog, QGridLayout, QLabel, QTextEdit, QVBoxLayout
 
-from ...config import Conf
+from angrmanagement.config import Conf
 
 
 class FuncDocDialog(QDialog):
