@@ -1,22 +1,23 @@
-from typing import Optional, TYPE_CHECKING
 from collections import OrderedDict
+from typing import TYPE_CHECKING, Optional
 
+from angr.analyses.decompiler.structured_codegen.c import CConstruct, CFunction, CFunctionCall, CStructField, CVariable
+from angr.sim_type import NamedTypeMixin, SimType, SimTypePointer, TypeRef
+from PySide6.QtGui import Qt
 from PySide6.QtWidgets import (
     QDialog,
-    QVBoxLayout,
+    QDialogButtonBox,
     QHBoxLayout,
     QLabel,
-    QPushButton,
     QLineEdit,
     QListWidget,
-    QDialogButtonBox,
+    QPushButton,
+    QVBoxLayout,
 )
-from PySide6.QtGui import Qt
-from angr.sim_type import SimType, TypeRef, SimTypePointer, NamedTypeMixin
-from angr.analyses.decompiler.structured_codegen.c import CVariable, CFunction, CConstruct, CFunctionCall, CStructField
 
 if TYPE_CHECKING:
     from angr.knowledge_plugins.functions import Function
+
     from angrmanagement.ui.views.code_view import CodeView
 
 
@@ -92,7 +93,6 @@ class RenameNode(QDialog):
     #
 
     def _init_widgets(self):
-
         # name label
 
         name_label = QLabel(self)
@@ -150,7 +150,6 @@ class RenameNode(QDialog):
     #
 
     def _on_name_changed(self, new_text):  # pylint:disable=unused-argument
-
         if self._name_box is None:
             # initialization is not done yet
             return
