@@ -1,7 +1,8 @@
 from functools import partial
 from typing import Callable
 
-from ...config import Conf
+from angrmanagement.config import Conf
+
 from .menu import Menu, MenuEntry, MenuSeparator
 
 
