@@ -1,10 +1,12 @@
 from .debug_toolbar import DebugToolbar
+from .feature_map_toolbar import FeatureMapToolbar
 from .file_toolbar import FileToolbar
 from .function_table_toolbar import FunctionTableToolbar
 from .nav_toolbar import NavToolbar
 
 __all__ = [
     "DebugToolbar",
+    "FeatureMapToolbar",
     "FileToolbar",
     "FunctionTableToolbar",
     "NavToolbar",
