@@ -1,22 +1,47 @@
-from .view import BaseView
-from .disassembly_view import DisassemblyView
-from .symexec_view import SymexecView
-from .functions_view import FunctionsView
-from .states_view import StatesView
-from .strings_view import StringsView
-from .console_view import ConsoleView
-from .code_view import CodeView
-from .interaction_view import InteractionView
-from .patches_view import PatchesView
-from .dep_view import DependencyView
-from .proximity_view import ProximityView
-from .types_view import TypesView
-from .hex_view import HexView
-from .log_view import LogView
-from .data_dep_view import DataDepView
-from .registers_view import RegistersView
-from .stack_view import StackView
-from .traces_view import TracesView
-from .trace_map_view import TraceMapView
 from .breakpoints_view import BreakpointsView
 from .call_explorer_view import CallExplorerView
+from .code_view import CodeView
+from .console_view import ConsoleView
+from .data_dep_view import DataDepView
+from .dep_view import DependencyView
+from .disassembly_view import DisassemblyView
+from .functions_view import FunctionsView
+from .hex_view import HexView
+from .interaction_view import InteractionView
+from .log_view import LogView
+from .patches_view import PatchesView
+from .proximity_view import ProximityView
+from .registers_view import RegistersView
+from .stack_view import StackView
+from .states_view import StatesView
+from .strings_view import StringsView
+from .symexec_view import SymexecView
+from .trace_map_view import TraceMapView
+from .traces_view import TracesView
+from .types_view import TypesView
+from .view import BaseView
+
+__all__ = [
+    "BreakpointsView",
+    "CallExplorerView",
+    "CodeView",
+    "ConsoleView",
+    "DataDepView",
+    "DependencyView",
+    "DisassemblyView",
+    "FunctionsView",
+    "HexView",
+    "InteractionView",
+    "LogView",
+    "PatchesView",
+    "ProximityView",
+    "RegistersView",
+    "StackView",
+    "StatesView",
+    "StringsView",
+    "SymexecView",
+    "TraceMapView",
+    "TracesView",
+    "TypesView",
+    "BaseView",
+]
