@@ -1,8 +1,9 @@
-from typing import Optional
+from typing import TYPE_CHECKING, Optional
 
 from PySide6.QtWidgets import QComboBox
 
-from angr.knowledge_plugins import FunctionManager
+if TYPE_CHECKING:
+    from angr.knowledge_plugins import FunctionManager
 
 
 class QFunctionComboBox(QComboBox):
@@ -35,7 +36,6 @@ class QFunctionComboBox(QComboBox):
     #
 
     def reload(self):
-
         if self._function_manager is None:
             return
 
@@ -52,7 +52,6 @@ class QFunctionComboBox(QComboBox):
     #
 
     def _on_current_index_changed(self):
-
         idx = self.currentIndex()
         if idx == -1:
             return
