@@ -1,21 +1,20 @@
-from typing import List, Optional
-import logging
-
-import PySide6
-from PySide6.QtGui import QPainter, QCursor, QBrush
-from PySide6.QtCore import Qt, QRectF
-from PySide6.QtWidgets import QApplication, QGraphicsSceneMouseEvent, QGraphicsSimpleTextItem
+from typing import TYPE_CHECKING, List, Optional
 
 from angr.analyses.disassembly import Value
+from PySide6.QtCore import QRectF, Qt
+from PySide6.QtGui import QBrush, QCursor, QPainter
+from PySide6.QtWidgets import QApplication, QGraphicsSceneMouseEvent, QGraphicsSimpleTextItem
+
+from angrmanagement.utils import get_comment_for_display, get_string_for_display, should_display_string_label
+
 from .qgraph_object import QCachedGraphicsItem
 from .qoperand import QOperand
-from ...utils import should_display_string_label, get_string_for_display, get_comment_for_display
 
-_l = logging.getLogger(__name__)
+if TYPE_CHECKING:
+    import PySide6
 
 
 class QInstruction(QCachedGraphicsItem):
-
     GRAPH_ADDR_SPACING = 20
     GRAPH_MNEMONIC_SPACING = 10
     GRAPH_OPERAND_SPACING = 2
@@ -57,7 +56,7 @@ class QInstruction(QCachedGraphicsItem):
 
         self._init_widgets()
 
-    def contextMenuEvent(self, event: PySide6.QtWidgets.QGraphicsSceneContextMenuEvent) -> None:
+    def contextMenuEvent(self, event: "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent") -> None:
         pass
 
     def mousePressEvent(self, event: QGraphicsSceneMouseEvent):
@@ -134,7 +133,6 @@ class QInstruction(QCachedGraphicsItem):
             self._comment = get_comment_for_display(self.instance.kb, self.insn.addr)
 
     def paint(self, painter, option, widget):  # pylint: disable=unused-argument
-
         painter.setRenderHints(QPainter.Antialiasing | QPainter.SmoothPixmapTransform)
 
         # background color
@@ -152,7 +150,6 @@ class QInstruction(QCachedGraphicsItem):
     #
 
     def _init_widgets(self):
-
         self.load_comment()
         self._operands.clear()
 
@@ -217,7 +214,6 @@ class QInstruction(QCachedGraphicsItem):
         self._layout_items_and_update_size()
 
     def _init_comments_or_string(self):
-
         # remove existing comments or strings
         if self._comment_items:
             for comm in self._comment_items:
@@ -245,7 +241,6 @@ class QInstruction(QCachedGraphicsItem):
             self._string_item.setBrush(Qt.gray)  # TODO: Expose it as a setting in Config
 
     def _layout_items_and_update_size(self):
-
         x, y = 0, 0
 
         # address
